@@ -187,9 +187,11 @@ class NumerousReportJob(NumerousBaseJob):
     def add_report_content(self):
         raise NotImplementedError
 
+
 class TerminateJob(Exception):
     pass
 
+
 class HibernateJob(Exception):
     pass
 
@@ -280,7 +282,6 @@ class NumerousSimulationJob(NumerousBaseJob):
         self.logger.debug(f'entering loop')
 
         details = ""
-        i = 0
         last_data = {}
 
         t = None
@@ -303,8 +304,10 @@ class NumerousSimulationJob(NumerousBaseJob):
                 if t_stop > 0:
                     self._completed = (1 - (t_stop - self._t) / (t_stop - self.app.start_time)) * 100
                     self.app.client.set_scenario_progress("running", ScenarioStatus.RUNNING, self._completed)
+                else:
+                    self.app.client.set_scenario_progress(f"Simulation time: {datetime.fromtimestamp(self._t)}",
+                                                          ScenarioStatus.RUNNING, 0)
 
-                i+=1
                 if self.app.backup.is_set():
                     self._save_states(t, 'backup', f"scheduled checkpoint @ {datetime.now()}")
                     self.app.backup.clear()
